@@ -1,9 +1,10 @@
 // Copyright (c) 2009 INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Principal_component_analysis/demo/Principal_component_analysis/PCA_demo.cpp $
-// $Id: PCA_demo.cpp 50996 2009-07-31 12:37:20Z palliez $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Principal_component_analysis/demo/Principal_component_analysis/PCA_demo.cpp $
+// $Id: PCA_demo.cpp 67117 2012-01-13 18:14:48Z lrineau $
 //
 //
 // Author(s)     : Pierre Alliez
@@ -24,6 +25,7 @@
 
 #include "MainWindow.h"
 #include <QApplication>
+#include <CGAL/Qt/resources.h>
 
 int main(int argc, char **argv)
 {
@@ -34,10 +36,7 @@ int main(int argc, char **argv)
 
   // Import resources from libCGALQt4.
   // See http://doc.trolltech.com/4.4/qdir.html#Q_INIT_RESOURCE
-  Q_INIT_RESOURCE(File);
-  Q_INIT_RESOURCE(Triangulation_2); 
-  Q_INIT_RESOURCE(Input);
-  Q_INIT_RESOURCE(CGAL);
+  CGAL_QT4_INIT_RESOURCES;
 
   MainWindow mainWindow;
   mainWindow.show();
