@@ -1,9 +1,10 @@
 // Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_linear_traits_2.h $
-// $Id: Arr_linear_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Arrangement_on_surface_2/include/CGAL/Arr_linear_traits_2.h $
+// $Id: Arr_linear_traits_2.h 67117 2012-01-13 18:14:48Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein          <wein@post.tau.ac.il>
@@ -1395,7 +1396,7 @@ public:
           {
             // Create a pair representing the point with its multiplicity,
             // which is always 1 for line segments.
-            std::pair<Point_2, unsigned int>   ip_mult (*ip, 1);
+            std::pair<Point_2,Multiplicity>   ip_mult (*ip, 1);
             *oi = make_object (ip_mult);
             oi++;
           }
@@ -1456,7 +1457,7 @@ public:
         // The two objects have the same supporting line, but they just share
         // a common endpoint. Thus we have an intersection point, but we leave
         // the multiplicity of this point undefined.
-        std::pair<Point_2, unsigned int>   ip_mult (ovlp.left(), 0);
+        std::pair<Point_2,Multiplicity>   ip_mult (ovlp.left(), 0);
         *oi = make_object (ip_mult);
         oi++;
       }
@@ -1511,68 +1512,72 @@ public:
     return Are_mergeable_2();
   }
 
+  /*! \class Merge_2
+   * A functor that merges two x-monotone arcs into one.
+   */
   class Merge_2
   {
+  protected:
+    typedef Arr_linear_traits_2<Kernel> Traits;
+
+    /*! The traits (in case it has state) */
+    const Traits* m_traits;
+    
+    /*! Constructor
+     * \param traits the traits (in case it has state)
+     */
+    Merge_2(const Traits* traits) : m_traits(traits) {}
+
+    friend class Arr_linear_traits_2<Kernel>;
+
   public:
     /*!
      * Merge two given x-monotone curves into a single curve (segment).
      * \param cv1 The first curve.
      * \param cv2 The second curve.
      * \param c Output: The merged curve.
-     * \pre The two curves are mergeable, that is they are supported by the
-     *      same line and share a common endpoint.
+     * \pre The two curves are mergeable.
      */
     void operator() (const X_monotone_curve_2& cv1,
                      const X_monotone_curve_2& cv2,
                      X_monotone_curve_2& c) const
     {
-      CGAL_precondition (! cv1.is_degenerate());
-      CGAL_precondition (! cv2.is_degenerate());
+      CGAL_precondition(m_traits->are_mergeable_2_object()(cv2, cv1));
 
-      Kernel                    kernel;
-      typename Kernel::Equal_2  equal = kernel.equal_2_object();
+      CGAL_precondition(!cv1.is_degenerate());
+      CGAL_precondition(!cv2.is_degenerate());
 
-      CGAL_precondition
-        (equal (cv1.supp_line(), 
-                cv2.supp_line()) ||
-         equal (cv1.supp_line(),
-                kernel.construct_opposite_line_2_object()(cv2.supp_line())));
+      Equal_2 equal = m_traits->equal_2_object();
 
       // Check which curve extends to the right of the other.
       if (cv1.has_right() && cv2.has_left() &&
-          equal (cv1.right(), cv2.left()))
+          equal(cv1.right(), cv2.left()))
       {
         // cv2 extends cv1 to the right.
         c = cv1;
 
         if (cv2.has_right())
-          c.set_right (cv2.right());
+          c.set_right(cv2.right());
         else
           c.set_right();      // Unbounded endpoint. 
       }
-      else
-      {
-        CGAL_precondition (cv2.has_right() && cv1.has_left() &&
-                           equal (cv2.right(), cv1.left()));
+      else {
+        CGAL_precondition(cv2.has_right() && cv1.has_left() &&
+                          equal(cv2.right(), cv1.left()));
 
         // cv1 extends cv2 to the right.
         c = cv2;
 
         if (cv1.has_right())
-          c.set_right (cv1.right());
+          c.set_right(cv1.right());
         else
           c.set_right();      // Unbounded endpoint.
       }
-
-      return;
     }
   };
 
   /*! Obtain a Merge_2 functor object. */
-  Merge_2 merge_2_object () const
-  {
-    return Merge_2();
-  }
+  Merge_2 merge_2_object () const { return Merge_2(this); }
   //@}
 
   /// \name Functor definitions for the landmarks point-location strategy.
