@@ -3,9 +3,10 @@
  * Copyright (c) 1995-2004 Exact Computation Project
  * All rights reserved.
  *
- * This file is part of CORE (http://cs.nyu.edu/exact/core/); you may
- * redistribute it under the terms of the Q Public License version 1.0.
- * See the file LICENSE.QPL distributed with CORE.
+ * This file is part of CORE (http://cs.nyu.edu/exact/core/).
+ * You can redistribute it and/or modify it under the terms of the GNU
+ * General Public License as published by the Free Software Foundation,
+ * either version 3 of the License, or (at your option) any later version.
  *
  * Licensees holding a valid commercial license may use this file in
  * accordance with the commercial license agreement provided with the
@@ -48,15 +49,15 @@
  * WWW URL: http://cs.nyu.edu/exact/
  * Email: exact@cs.nyu.edu
  *
- * $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Core/include/CGAL/CORE/RefCount.h $
- * $Id: RefCount.h 28567 2006-02-16 14:30:13Z lsaboret $
+ * $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Core/include/CGAL/CORE/RefCount.h $
+ * $Id: RefCount.h 67117 2012-01-13 18:14:48Z lrineau $
  ***************************************************************************/
 
 
 #ifndef _CORE_REFCOUNT_H_
 #define _CORE_REFCOUNT_H_
 
-CORE_BEGIN_NAMESPACE
+namespace CORE { 
 
 template<class Deriving>
 class RCRepImpl {
@@ -94,14 +95,17 @@ public:
   T& getRep() {
     return *rep;
   }
+
+  
   /// clone data
   void makeCopy() {
     if (rep->getRefCount() > 1) {
       T* oldValue = rep;
       rep->decRef(); // safe since rep has been referred at least once.
-      rep = oldValue ? new T(*oldValue) : 0;
+      rep = oldValue ? new T(*oldValue) : 0; 
     }
   }
+ 
 #ifdef CORE_RC_DEBUG
   /// get counter
   int getRefCount() const {
@@ -110,5 +114,5 @@ public:
 #endif
 };
 
-CORE_END_NAMESPACE
+} //namespace CORE
 #endif // _CORE_REFCOUNT_H_
