@@ -1,9 +1,10 @@
 // Copyright (c) 2005 Rijksuniversiteit Groningen (Netherlands)
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Skin_surface_3/include/CGAL/Compute_anchor_3.h $
-// $Id: Compute_anchor_3.h 40822 2007-11-07 16:51:18Z ameyer $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Skin_surface_3/include/CGAL/Compute_anchor_3.h $
+// $Id: Compute_anchor_3.h 67117 2012-01-13 18:14:48Z lrineau $
 // 
 //
 // Author(s)     : Nico Kruithof <Nico@cs.rug.nl>
@@ -23,7 +24,7 @@
 #include <CGAL/Regular_triangulation_3.h>
 #include <CGAL/Triangulation_simplex_3.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template < class RegularTriangulation_3>
 class Compute_anchor_3
@@ -443,7 +444,10 @@ compute_anchor_vor (Vertex_handle const v) {
           for (adj_vertex = adj_vertices.begin(); 
                adj_vertex != adj_vertices.end();
                adj_vertex++) {
-            if (v_other != (*adj_vertex)) {
+            if ((v_other != (*adj_vertex)) && (!reg.is_infinite(*adj_vertex))) {
+              CGAL_assertion(!reg.is_infinite(v));
+              CGAL_assertion(!reg.is_infinite(v_other));
+              CGAL_assertion(!reg.is_infinite(*adj_vertex));
               side = test_anchor(v->point(), v_other->point(),
                                  (*adj_vertex)->point());
               if (side==ZERO) {
@@ -585,6 +589,6 @@ Compute_anchor_3<RegularTriangulation3>::compute_anchor_vor (Facet const &f) {
 }
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_COMPUTE_ANCHOR_3_H
