@@ -1,9 +1,10 @@
 // Copyright (c) 1997  INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Triangulation_2/include/CGAL/Delaunay_triangulation_2.h $
-// $Id: Delaunay_triangulation_2.h 63930 2011-06-07 08:20:54Z sloriot $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Triangulation_2/include/CGAL/Delaunay_triangulation_2.h $
+// $Id: Delaunay_triangulation_2.h 67417 2012-01-24 17:25:20Z sloriot $
 // 
 //
 // Author(s)     : Mariette Yvinec
@@ -282,9 +283,9 @@ public:
   std::ptrdiff_t
   insert( InputIterator first, InputIterator last,
           typename boost::enable_if<
-            boost::is_base_of<
-                Point,
-                typename std::iterator_traits<InputIterator>::value_type
+            boost::is_convertible<
+                typename std::iterator_traits<InputIterator>::value_type,
+                Point
             >
           >::type* = NULL
   )
@@ -359,7 +360,7 @@ public:
   insert( InputIterator first,
           InputIterator last,
           typename boost::enable_if<
-            boost::is_same<
+            boost::is_convertible<
               typename std::iterator_traits<InputIterator>::value_type,
               std::pair<Point,typename internal::Info_check<typename Tds::Vertex>::type>
             > >::type* =NULL
@@ -374,8 +375,8 @@ public:
           boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > last,
           typename boost::enable_if<
             boost::mpl::and_<
-              boost::is_same< typename std::iterator_traits<InputIterator_1>::value_type, Point >,
-              boost::is_same< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Tds::Vertex>::type >
+              boost::is_convertible< typename std::iterator_traits<InputIterator_1>::value_type, Point >,
+              boost::is_convertible< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Tds::Vertex>::type >
             >
           >::type* =NULL
   )
@@ -917,10 +918,27 @@ remove_and_give_new_faces(Vertex_handle v, OutputItFaces fit)
         afi++) *fit++ = afi;
   }
   else {
+    #ifdef CGAL_HAS_THREADS  
+    static boost::thread_specific_ptr< int > maxd_ptr;
+    static boost::thread_specific_ptr< std::vector<Face_handle> > f_ptr;
+    static boost::thread_specific_ptr< std::vector<int> > i_ptr;
+    static boost::thread_specific_ptr< std::vector<Vertex_handle> > w_ptr;
+    if (maxd_ptr.get() == NULL) {
+      maxd_ptr.reset(new int(30));
+      f_ptr.reset(new std::vector<Face_handle>(*maxd_ptr));
+      i_ptr.reset(new std::vector<int>(*maxd_ptr));
+      w_ptr.reset(new std::vector<Vertex_handle>(*maxd_ptr));
+    }
+    int& maxd=*maxd_ptr;
+    std::vector<Face_handle>& f=*f_ptr;
+    std::vector<int>& i=*i_ptr;
+    std::vector<Vertex_handle>& w=*w_ptr;
+    #else
     static int maxd=30;
     static std::vector<Face_handle> f(maxd);
     static std::vector<int> i(maxd);
     static std::vector<Vertex_handle> w(maxd);
+    #endif
     int d;
     remove_degree_init(v,f,w,i,d,maxd);
     remove_degree_triangulate(v,f,w,i,d);
@@ -944,10 +962,27 @@ remove(Vertex_handle v)
 
   if ( this->dimension() <= 1) { Triangulation::remove(v); return; }
 
+  #ifdef CGAL_HAS_THREADS  
+  static boost::thread_specific_ptr< int > maxd_ptr;
+  static boost::thread_specific_ptr< std::vector<Face_handle> > f_ptr;
+  static boost::thread_specific_ptr< std::vector<int> > i_ptr;
+  static boost::thread_specific_ptr< std::vector<Vertex_handle> > w_ptr;
+  if (maxd_ptr.get() == NULL) {
+    maxd_ptr.reset(new int(30));
+    f_ptr.reset(new std::vector<Face_handle>(*maxd_ptr));
+    i_ptr.reset(new std::vector<int>(*maxd_ptr));
+    w_ptr.reset(new std::vector<Vertex_handle>(*maxd_ptr));
+  }
+  int& maxd=*maxd_ptr;
+  std::vector<Face_handle>& f=*f_ptr;
+  std::vector<int>& i=*i_ptr;
+  std::vector<Vertex_handle>& w=*w_ptr;
+  #else
   static int maxd=30;
   static std::vector<Face_handle> f(maxd);
   static std::vector<int> i(maxd);
   static std::vector<Vertex_handle> w(maxd);
+  #endif
   remove_degree_init(v,f,w,i,d,maxd);
   if (d == 0) return; //  dim is going down
   remove_degree_triangulate(v,f,w,i,d);
@@ -2090,10 +2125,27 @@ move_if_no_collision(Vertex_handle v, const Point &p) {
 
   {
     int d;
+    #ifdef CGAL_HAS_THREADS  
+    static boost::thread_specific_ptr< int > maxd_ptr;
+    static boost::thread_specific_ptr< std::vector<Face_handle> > f_ptr;
+    static boost::thread_specific_ptr< std::vector<int> > i_ptr;
+    static boost::thread_specific_ptr< std::vector<Vertex_handle> > w_ptr;
+    if (maxd_ptr.get() == NULL) {
+      maxd_ptr.reset(new int(30));
+      f_ptr.reset(new std::vector<Face_handle>(*maxd_ptr));
+      i_ptr.reset(new std::vector<int>(*maxd_ptr));
+      w_ptr.reset(new std::vector<Vertex_handle>(*maxd_ptr));
+    }
+    int& maxd=*maxd_ptr;
+    std::vector<Face_handle>& f=*f_ptr;
+    std::vector<int>& i=*i_ptr;
+    std::vector<Vertex_handle>& w=*w_ptr;
+    #else
     static int maxd=30;
     static std::vector<Face_handle> f(maxd);
     static std::vector<int> i(maxd);
     static std::vector<Vertex_handle> w(maxd);
+    #endif
     remove_degree_init(v,f,w,i,d,maxd);
     remove_degree_triangulate(v,f,w,i,d);
   }
@@ -2308,10 +2360,27 @@ move_if_no_collision_and_give_new_faces(Vertex_handle v,
 
 
   {
+    #ifdef CGAL_HAS_THREADS  
+    static boost::thread_specific_ptr< int > maxd_ptr;
+    static boost::thread_specific_ptr< std::vector<Face_handle> > f_ptr;
+    static boost::thread_specific_ptr< std::vector<int> > i_ptr;
+    static boost::thread_specific_ptr< std::vector<Vertex_handle> > w_ptr;
+    if (maxd_ptr.get() == NULL) {
+      maxd_ptr.reset(new int(30));
+      f_ptr.reset(new std::vector<Face_handle>(*maxd_ptr));
+      i_ptr.reset(new std::vector<int>(*maxd_ptr));
+      w_ptr.reset(new std::vector<Vertex_handle>(*maxd_ptr));
+    }
+    int& maxd=*maxd_ptr;
+    std::vector<Face_handle>& f=*f_ptr;
+    std::vector<int>& i=*i_ptr;
+    std::vector<Vertex_handle>& w=*w_ptr;
+    #else
     static int maxd=30;
     static std::vector<Face_handle> f(maxd);
     static std::vector<int> i(maxd);
     static std::vector<Vertex_handle> w(maxd);
+    #endif
     int d;
     remove_degree_init(v,f,w,i,d,maxd);
     remove_degree_triangulate(v,f,w,i,d);
