@@ -2,8 +2,8 @@
 // 
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 // 
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // 
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Number_types/include/CGAL/Gmpfr.h $
-// $Id: Gmpfr.h 61900 2011-03-22 07:59:52Z penarand $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Number_types/include/CGAL/Gmpfr.h $
+// $Id: Gmpfr.h 67093 2012-01-13 11:22:39Z lrineau $
 // 
 // Author: Luis Pearanda <luis.penaranda@gmx.com>
 
@@ -156,6 +156,7 @@ public INTERN_RET::Real_embeddable_traits_base<Gmpfr,CGAL::Tag_true>{
 }
 
 #include <CGAL/GMP/Gmpfr_type.h>
+#include <CGAL/GMP_arithmetic_kernel.h>
 
 #endif  // CGAL_GMPFR_H
 
