@@ -1,13 +1,14 @@
-// Copyright (c) 1999  Utrecht University (The Netherlands),
-// ETH Zurich (Switzerland), Freie Universitaet Berlin (Germany),
-// INRIA Sophia-Antipolis (France), Martin-Luther-University Halle-Wittenberg
-// (Germany), Max-Planck-Institute Saarbruecken (Germany), RISC Linz (Austria),
-// and Tel-Aviv University (Israel).  All rights reserved.
+// Copyright (c) 1999  
+// Utrecht University (The Netherlands),
+// ETH Zurich (Switzerland),
+// INRIA Sophia-Antipolis (France),
+// Max-Planck-Institute Saarbruecken (Germany),
+// and Tel-Aviv University (Israel).  All rights reserved. 
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -15,8 +16,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/STL_Extension/include/CGAL/Handle_for_virtual.h $
-// $Id: Handle_for_virtual.h 45176 2008-08-27 15:36:24Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/STL_Extension/include/CGAL/Handle_for_virtual.h $
+// $Id: Handle_for_virtual.h 67093 2012-01-13 11:22:39Z lrineau $
 // 
 //
 // Author(s)     : Stefan Schirra
@@ -27,8 +28,9 @@
 
 #include <CGAL/basic.h>
 #include <typeinfo>
+#include <cstddef>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 class Ref_counted_virtual
 {
@@ -65,6 +67,8 @@ class Handle_for_virtual
 {
   public:
 
+    typedef std::ptrdiff_t Id_type ;
+    
     Handle_for_virtual(const RefCounted& rc)
     {
       ptr = new RefCounted(rc);
@@ -118,13 +122,10 @@ class Handle_for_virtual
 	ptr = new T(rc);
     }
 
-    bool
-    identical( const Handle_for_virtual& h) const
-    { return ptr == h.ptr; }
+    Id_type id() const { return Ptr() - static_cast<RefCounted const*>(0); }
+    
+    bool identical( const Handle_for_virtual& h) const { return Ptr() == h.Ptr(); }
 
-    long int
-    id() const
-    { return reinterpret_cast<long int>(&*ptr); }
 
     void
     swap(Handle_for_virtual & h)
@@ -174,6 +175,9 @@ protected:
     RefCounted * ptr;
 };
 
-CGAL_END_NAMESPACE
+template <class RefCounted>
+inline bool identical(const Handle_for_virtual<RefCounted> &h1, const Handle_for_virtual<RefCounted> &h2) { return h1.identical(h2); }
+
+} //namespace CGAL
 
 #endif // CGAL_HANDLE_FOR_VIRTUAL_H
