@@ -1,13 +1,14 @@
-// Copyright (c) 1997,2005  Utrecht University (The Netherlands),
-// ETH Zurich (Switzerland), Freie Universitaet Berlin (Germany),
-// INRIA Sophia-Antipolis (France), Martin-Luther-University Halle-Wittenberg
-// (Germany), Max-Planck-Institute Saarbruecken (Germany), RISC Linz (Austria),
-// and Tel-Aviv University (Israel).  All rights reserved.
+// Copyright (c) 1997,2005  
+// Utrecht University (The Netherlands),
+// ETH Zurich (Switzerland),
+// INRIA Sophia-Antipolis (France),
+// Max-Planck-Institute Saarbruecken (Germany),
+// and Tel-Aviv University (Israel).  All rights reserved. 
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -15,8 +16,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Stream_support/include/CGAL/IO/Scanner_OFF.h $
-// $Id: Scanner_OFF.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Stream_support/include/CGAL/IO/Scanner_OFF.h $
+// $Id: Scanner_OFF.h 67241 2012-01-18 10:10:14Z afabri $
 // 
 //
 // Author(s)     : Lutz Kettner  <kettner@mpi-sb.mpg.de>
@@ -29,11 +30,12 @@
 #include <iterator>
 #include <vector>
 #include <utility>
+#include <limits>
 #include <CGAL/IO/File_scanner_OFF.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
-// The Facet_iterator's value type is vector<Integer32>
+// The Facet_iterator's value type is vector<std::size_t>
 // that contains the vertex indices.
 
 template <class Pt>
@@ -47,7 +49,7 @@ public:
     typedef const Pt&                reference;
 private:
     File_scanner_OFF*  m_scan;
-    std::ptrdiff_t     m_cnt;
+    std::size_t        m_cnt;
     Pt                 m_point;
 
     void next_vertex() {
@@ -64,13 +66,13 @@ public:
     typedef File_scanner_OFF                   Scanner;
     typedef I_Scanner_OFF_vertex_iterator<Pt>  Self;
 
-    I_Scanner_OFF_vertex_iterator( int cnt) : m_scan(0), m_cnt(cnt+1) {}
+  I_Scanner_OFF_vertex_iterator(std::size_t cnt) : m_scan(0), m_cnt(cnt+1) {}
     I_Scanner_OFF_vertex_iterator( Scanner& s, int cnt)
         : m_scan(&s), m_cnt(cnt)
     {
         next_vertex();
     }
-    std::ptrdiff_t  count()           const { return m_cnt; }
+    std::size_t  count()              const { return m_cnt; }
     bool   operator==( const Self& i) const { return m_cnt == i.m_cnt; }
     bool   operator!=( const Self& i) const { return m_cnt != i.m_cnt; }
     Self&  operator++() {
@@ -105,7 +107,7 @@ public:
     typedef const value_type&                               reference;
 private:
     File_scanner_OFF*  m_scan;
-    std::ptrdiff_t     m_cnt;
+    std::size_t        m_cnt;
     value_type         m_current;
     
 
@@ -129,7 +131,7 @@ public:
     {
         next();
     }
-    std::ptrdiff_t  count()           const { return m_cnt; }
+    std::size_t  count()              const { return m_cnt; }
     bool   operator==( const Self& i) const { return m_cnt == i.m_cnt; }
     bool   operator!=( const Self& i) const { return m_cnt != i.m_cnt; }
     Self&  operator++() {
@@ -152,24 +154,26 @@ class I_Scanner_OFF_facet_iterator
 {
 public:
     typedef std::input_iterator_tag  iterator_category;
-    typedef std::vector< Integer32>  value_type;
+  typedef std::vector<std::size_t>  value_type;
     typedef std::ptrdiff_t           difference_type;
     typedef value_type*              pointer;
     typedef value_type&              reference;
 private:
     File_scanner_OFF*  m_scan;
-    std::ptrdiff_t     m_cnt;
+    std::size_t        m_cnt;
     value_type         m_indices;
 
     void next_facet() {
         CGAL_assertion( m_scan != NULL);
         if ( m_cnt < m_scan->size_of_facets()) {
             m_indices.erase( m_indices.begin(), m_indices.end());
-            Integer32 no;
+            std::size_t no;
             m_scan->scan_facet( no, m_cnt);
             m_indices.reserve( no);
-            Integer32 index = -1;
-            for ( Integer32 i = 0; i < no; ++i) {
+            std::size_t index = (std::numeric_limits<std::size_t>::max)(); 
+            //  A huge value helps to detect a potential
+            //  error in the function scan_facet_vertex_index
+            for (std::size_t i = 0; i < no; ++i) {
                 m_scan->scan_facet_vertex_index( index, m_cnt);
                 m_indices.push_back( index);
             }
@@ -187,13 +191,13 @@ public:
     typedef I_Scanner_OFF_facet_iterator  Self;
     typedef value_type::iterator          iterator;
 
-    I_Scanner_OFF_facet_iterator( int cnt) : m_scan(0), m_cnt(cnt+1) {}
-    I_Scanner_OFF_facet_iterator( Scanner& s, int cnt)
+  I_Scanner_OFF_facet_iterator( std::size_t cnt) : m_scan(0), m_cnt(cnt+1) {}
+  I_Scanner_OFF_facet_iterator( Scanner& s, std::size_t cnt)
         : m_scan(&s), m_cnt(cnt)
     {
         next_facet();
     }
-    std::ptrdiff_t  count()          const { return m_cnt; }
+    std::size_t  count()             const { return m_cnt; }
     bool  operator==( const Self& i) const { return m_cnt == i.m_cnt; }
     bool  operator!=( const Self& i) const { return m_cnt != i.m_cnt; }
     Self& operator++() {
@@ -265,9 +269,9 @@ public:
     Scanner_OFF( std::istream& in, const File_header_OFF& header)
         : m_scan( in, header) {}
 
-    int  size_of_vertices()   const { return m_scan.size_of_vertices(); }
-    int  size_of_halfedges()  const { return m_scan.size_of_halfedges();}
-    int  size_of_facets()     const { return m_scan.size_of_facets();   }
+    std::size_t  size_of_vertices()   const { return m_scan.size_of_vertices(); }
+    std::size_t  size_of_halfedges()  const { return m_scan.size_of_halfedges();}
+    std::size_t  size_of_facets()     const { return m_scan.size_of_facets();   }
 
     bool verbose()            const { return m_scan.verbose();          }
     bool skel()               const { return m_scan.skel();             }
@@ -298,6 +302,6 @@ public:
     }
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 #endif // CGAL_IO_SCANNER_OFF_H //
 // EOF //
