@@ -1,9 +1,10 @@
 // Copyright (c) 2002,2011 Utrecht University (The Netherlands).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Spatial_searching/include/CGAL/Incremental_neighbor_search.h $
-// $Id: Incremental_neighbor_search.h 64637 2011-07-06 11:11:58Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Spatial_searching/include/CGAL/Incremental_neighbor_search.h $
+// $Id: Incremental_neighbor_search.h 67117 2012-01-13 18:14:48Z lrineau $
 // 
 //
 // Author(s)     : Hans Tangelder (<hanst@cs.uu.nl>)
@@ -43,7 +44,7 @@ namespace CGAL {
     typedef typename SearchTraits::Point_d Point_d;
     typedef typename SearchTraits::FT FT;
     typedef typename Tree::Point_d_iterator Point_d_iterator;
-    typedef typename Tree::Node_handle Node_handle;
+    typedef typename Tree::Node_const_handle Node_const_handle;
     typedef typename Tree::Splitter Splitter;
     typedef Kd_tree_rectangle<FT> Node_box;
     typedef typename Distance::Query_item Query_item;
@@ -53,12 +54,12 @@ namespace CGAL {
     private:
 
       Node_box* the_box;
-      Node_handle the_node;
+      Node_const_handle the_node;
 
     public:
 
       // constructor
-      Cell (Node_box* Nb, Node_handle N)
+      Cell (Node_box* Nb, Node_const_handle N)
       :the_box(Nb), the_node(N)
       {}
 
@@ -68,7 +69,7 @@ namespace CGAL {
 	return the_box;
       }
 
-      Node_handle    
+      Node_const_handle    
       node() 
       {
 	return the_node;
@@ -86,43 +87,38 @@ namespace CGAL {
     typedef std::vector<Point_with_transformed_distance*> Point_with_distance_vector;
     typedef std::vector<FT> Distance_vector;
 
-    iterator *start;
-    iterator *past_the_end;
+    //data members
+    const Tree& m_tree;
+    Query_item m_query;
+    Distance m_dist;
+    FT m_Eps; 
+    bool m_search_nearest;    
 
   public:
 
     // constructor
-    Incremental_neighbor_search(Tree& tree, const Query_item& q,
+    Incremental_neighbor_search(const Tree& tree, const Query_item& q,
 				FT Eps=FT(0.0), bool search_nearest=true, 
-				const Distance& tr=Distance())
-    {
-      start = new iterator(tree,q,tr,Eps,search_nearest);
-      past_the_end = new iterator();
-    }
+				const Distance& tr=Distance()): 
+          m_tree(tree),m_query(q),m_dist(tr),m_Eps(Eps),m_search_nearest(search_nearest)
+    {}
 
-    // destructor
-    ~Incremental_neighbor_search() 
+    iterator 
+    begin() const
     {
-      delete start;
-      delete past_the_end;
+      return iterator(m_tree,m_query,m_dist,m_Eps,m_search_nearest);
     }
 
     iterator 
-    begin() 
+    end() const
     {
-      return *start;
-    }
-
-    iterator 
-    end() 
-    {
-      return *past_the_end;
+      return iterator();
     }
 
     std::ostream&  
     statistics(std::ostream& s) 
     {
-      start->statistics(s);
+      begin()->statistics(s);
       return s;
     }
 
@@ -190,7 +186,7 @@ namespace CGAL {
         return *this;
       }      
       
-      Point_with_transformed_distance& 
+      const Point_with_transformed_distance& 
       operator* () const
       {
 	return *(*ptr);
@@ -360,8 +356,8 @@ namespace CGAL {
 	}
 
 	// * operator
-	Point_with_transformed_distance& 
-	operator* () 
+	const Point_with_transformed_distance& 
+	operator* () const
 	{    
 	  return *(Item_PriorityQueue.top());
 	}
@@ -386,7 +382,7 @@ namespace CGAL {
 
 	// Print statistics of the general priority search process.
 	std::ostream& 
-	statistics (std::ostream& s) 
+	statistics (std::ostream& s) const
 	{
 	  s << "General priority search statistics:" << std::endl;
 	  s << "Number of internal nodes visited:" << 
@@ -443,7 +439,7 @@ namespace CGAL {
 	  while ((!next_neighbour_found) && (!PriorityQueue.empty())) {
                 
 	    Cell_with_distance* The_node_top = PriorityQueue.top();
-	    Node_handle N = The_node_top->first->node();
+	    Node_const_handle N = The_node_top->first->node();
 	    Node_box* B = The_node_top->first->box();
 	    PriorityQueue.pop();
 	    delete The_node_top->first;
