@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kinetic_data_structures/include/CGAL/Kinetic/IO/Qt_moving_points_2.h $
-// $Id: Qt_moving_points_2.h 42713 2008-04-01 18:02:51Z drussel $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Kinetic_data_structures/include/CGAL/Kinetic/IO/Qt_moving_points_2.h $
+// $Id: Qt_moving_points_2.h 67093 2012-01-13 11:22:39Z lrineau $
 // 
 //
 // Author(s)     : Daniel Russel <drussel@alumni.princeton.edu>
@@ -27,7 +27,7 @@
 #include <CGAL/Kinetic/Listener.h>
 #include <sstream>
 
-CGAL_KINETIC_BEGIN_NAMESPACE
+namespace CGAL { namespace Kinetic {
 
 //! A graphical moving point set
 /*!  This allows a set of moving points to be used in a
@@ -52,7 +52,7 @@ protected:
   //  friend class CGAL::Kinetic::Simulator_objects_listener<Simulator_listener, This>;
   typedef typename Traits::Static_kernel::FT NT;
   //class Guil;
-  CGAL_KINETIC_LISTEN1(Simulator, DIRECTION_OF_TIME, reverse_time());
+  CGAL_KINETIC_LISTEN1(Simulator, DIRECTION_OF_TIME, reverse_time())
 public:
   //typedef typename CGAL::Ref_counted_pointer<This> Pointer;
   //typedef typename CGAL::Const_ref_counted_pointer<This> Const_handle;
@@ -133,7 +133,7 @@ public:
     }*/
 
 protected:
-  CGAL_KINETIC_LISTEN1(GUI,PICTURE_IS_VALID, draw());
+  CGAL_KINETIC_LISTEN1(GUI,PICTURE_IS_VALID, draw())
   /*class Guil: public Gui_listener
   {
     typedef Gui_listener P;
@@ -242,5 +242,5 @@ void Qt_moving_points_2<T,G>::reverse_time()
 }
 
 
-CGAL_KINETIC_END_NAMESPACE
+} } //namespace CGAL::Kinetic
 #endif                                            // guard
