@@ -1,9 +1,10 @@
 // Copyright (c) 2009 INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Mesh_3/include/CGAL/Mesh_3/mesh_standard_criteria.h $
-// $Id: mesh_standard_criteria.h 53504 2009-12-18 17:15:58Z stayeb $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Mesh_3/include/CGAL/Mesh_3/mesh_standard_criteria.h $
+// $Id: mesh_standard_criteria.h 67117 2012-01-13 18:14:48Z lrineau $
 //
 //
 // Author(s)     : Stephane Tayeb
@@ -49,7 +50,7 @@ public:
   typedef typename Visitor_::Handle Handle;
 
   /// Destructor
-  virtual ~Abstract_criterion() { };
+  virtual ~Abstract_criterion() {}
 
   void accept(Visitor_& v) const { do_accept(v); }
   Badness is_bad(const Handle& h) const { return do_is_bad(h); }
@@ -92,10 +93,10 @@ public:
   Criterion_visitor(const Handle_& h)
     : handle_(h)
     , badness_()
-    , criterion_counter_(0) { };
+    , criterion_counter_(0) {}
 
   // Destructor
-  ~Criterion_visitor() { };
+  ~Criterion_visitor() {}
 
   Badness badness() const
   {
@@ -152,14 +153,14 @@ class Criteria
 
 public:
   /// Constructor
-  Criteria() { };
+  Criteria() {}
 
   /// Copy constructor
   Criteria(const Self& rhs)
     : criterion_vector_(rhs.criterion_vector_.clone())    { }
 
   /// Destructor
-  ~Criteria() { }; // ptr_vector do the job of criterion deleting
+  ~Criteria() {} // ptr_vector do the job of criterion deleting
 
   /// Add a criterion
   void add(Criterion* criterion)
