@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Polynomial/include/CGAL/Polynomial/Polynomial_type.h $
-// $Id: Polynomial_type.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Polynomial/include/CGAL/Polynomial/Polynomial_type.h $
+// $Id: Polynomial_type.h 67240 2012-01-18 09:57:46Z afabri $
 //
 //
 // Author(s)     : Michael Hemmer <hemmer@informatik.uni-mainz.de> 
@@ -44,7 +44,11 @@ typename CGAL::internal::Innermost_coefficient_type<T>::Type , 2>::Type
 #include <sstream>
 #include <CGAL/Polynomial/misc.h>
 
-CGAL_BEGIN_NAMESPACE
+#ifdef CGAL_HAS_THREADS
+#  include <boost/thread/tss.hpp>
+#endif
+
+namespace CGAL {
 
 template <class NT> class Polynomial;
 template <class NT> class Scalar_factor_traits;
@@ -216,7 +220,10 @@ public:
   typedef typename Rep::iterator  iterator;
   //! container's const iterator (random access)
   typedef typename Rep::const_iterator const_iterator;
+  //! the Self type
+  typedef Polynomial<NT> Self; 
   //@}
+  
 
 protected:
   //! \name Protected methods
@@ -256,18 +263,22 @@ protected:
 //
 // Constructors of Polynomial<NT>
 //
-
+private:
+    static Self& get_default_instance(){
+      #ifdef CGAL_HAS_THREADS  
+        static boost::thread_specific_ptr< Self > safe_x_ptr;
+          if (safe_x_ptr.get() == NULL) 
+            safe_x_ptr.reset(new Self(0));
+        return *safe_x_ptr.get();  
+      #else
+        static Self x = Self(0);
+        return x;
+      #endif        
+    }
 public:
     //! \name Constructors
-    //! default constructor: a new polynomial of undefined value.
-    Polynomial() 
-      : Base( Rep(internal::Creation_tag(), 1) ) { 
-      coeff(0) = NT(0); 
-    }
-      
-     
     //! copy constructor: copy existing polynomial (shares rep)
-    Polynomial(const Polynomial<NT>& p) : Base(static_cast<const Base&>(p)) {}
+    Polynomial(const Self& p = get_default_instance()) : Base(static_cast<const Base&>(p)) {}
         
     //! construct the constant polynomial a0 from any type convertible to NT
     template <class T>
@@ -276,7 +287,7 @@ public:
       { coeff(0) = NT(a0); reduce(); simplify_coefficients(); } 
           
     //! construct the constant polynomial a0
-    Polynomial(const NT& a0)
+    explicit Polynomial(const NT& a0)
       : Base(Rep(1, &a0))
       { reduce(); simplify_coefficients(); }
       
@@ -368,7 +379,7 @@ public:
     /*! The degree of the zero polynomial is 0.
      *  The degree of an undefined polynomial is -1.
      */
-    int degree() const { return this->ptr()->coeff.size()-1; } 
+  int degree() const { return static_cast<int>(this->ptr()->coeff.size())-1; } 
 
     //! const access to the coefficient of x^i
     const NT& operator[](unsigned int i) const {
@@ -540,7 +551,7 @@ public:
      *  Also available as non-member function.
      */
     CGAL::Sign sign() const {
-//        BOOST_STATIC_ASSERT( (boost::is_same< typename Real_embeddable_traits<NT>::Is_real_embeddable,
+//        CGAL_static_assertion( (boost::is_same< typename Real_embeddable_traits<NT>::Is_real_embeddable,
 //                              CGAL::Tag_true>::value) );
       return CGAL::sign(lcoeff());
     }
@@ -552,7 +563,7 @@ public:
       CGAL_precondition(degree() >= 0);
       CGAL_precondition(p2.degree() >= 0);
 
-      if (is_identical(p2)) return CGAL::EQUAL;
+      if (this->is_identical(p2)) return CGAL::EQUAL;
 
       int d1 = degree();
       int d2 = p2.degree();
@@ -843,7 +854,7 @@ public:
 // ...for polynomials
     Polynomial<NT>& operator += (const Polynomial<NT>& p1) {
       this->copy_on_write();
-      int d = std::min(degree(),p1.degree()), i;
+      int d = (std::min)(degree(),p1.degree()), i;
       for(i=0; i<=d; ++i) coeff(i) += p1[i];
       while (i<=p1.degree()) this->ptr()->coeff.push_back(p1[i++]);
       reduce(); return (*this);
@@ -852,7 +863,7 @@ public:
     Polynomial<NT>& operator -= (const Polynomial<NT>& p1) 
       {
         this->copy_on_write();
-        int d = std::min(degree(),p1.degree()), i;
+        int d = (std::min)(degree(),p1.degree()), i;
         for(i=0; i<=d; ++i) coeff(i) -= p1[i];
         while (i<=p1.degree()) this->ptr()->coeff.push_back(-p1[i++]);
         reduce(); return (*this);
@@ -1412,7 +1423,7 @@ inline static void swallow(std::istream &is, char d) {
 template <class NT>
 Polynomial<NT> Polynomial<NT>::input_ascii(std::istream &is) {
   char c;
-  int degr = -1, i;
+  int degr = -1, i=0;
 
   internal::swallow(is, 'P');
   internal::swallow(is, '[');
@@ -1449,7 +1460,7 @@ struct Needs_parens_as_product<Polynomial<COEFF> >{
 
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #undef CGAL_icoeff
 #undef CGAL_int
