@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kinetic_data_structures/include/CGAL/Polynomial/internal/Filtered_rational/Filtered_rational_traits.h $
-// $Id: Filtered_rational_traits.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Kinetic_data_structures/include/CGAL/Polynomial/internal/Filtered_rational/Filtered_rational_traits.h $
+// $Id: Filtered_rational_traits.h 67093 2012-01-13 11:22:39Z lrineau $
 // 
 //
 // Author(s)     : Daniel Russel <drussel@alumni.princeton.edu>
@@ -132,7 +132,7 @@
 
 //std::cout << "UCName of " << f << " and " << fp << std::endl;
 
-                                CGAL_POLYNOMIAL_BEGIN_INTERNAL_NAMESPACE
+                                namespace CGAL { namespace POLYNOMIAL { namespace internal {
 
                                 template <class Filter_traits_t, template<class Fn> class Rational_traits = internal::Rational_traits_base>
                                 class Filtered_rational_traits
@@ -299,6 +299,6 @@
                                         Exact_to_interval_converter efc_;
                                 };
 
-                                CGAL_POLYNOMIAL_END_INTERNAL_NAMESPACE
+                                } } } //namespace CGAL::POLYNOMIAL::internal
 //#undef DF_UNARY_CONSTUCTION
 #endif
