@@ -1,9 +1,10 @@
 // Copyright (c) 1997-2007  ETH Zurich (Switzerland).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/QP_solver/include/CGAL/QP_solver/QP_partial_filtered_pricing.h $
-// $Id: QP_partial_filtered_pricing.h 38453 2007-04-27 00:34:44Z gaertner $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/QP_solver/include/CGAL/QP_solver/QP_partial_filtered_pricing.h $
+// $Id: QP_partial_filtered_pricing.h 67117 2012-01-13 18:14:48Z lrineau $
 // 
 //
 // Author(s)     : Sven Schoenherr
@@ -23,11 +24,22 @@
 #ifndef CGAL_QP_PARTIAL_FILTERED_PRICING_H
 #define CGAL_QP_PARTIAL_FILTERED_PRICING_H
 
+// MSVC detection
+#include <boost/config.hpp>
+
 // includes
 #include <CGAL/QP_solver/QP__partial_base.h>
 #include <CGAL/QP_solver/QP__filtered_base.h>
 
-CGAL_BEGIN_NAMESPACE
+
+// MSVC complains about inheritance through dominance when only one
+// base implements virtual functions from the top of the diamond.
+#if defined(BOOST_MSVC)
+#  pragma warning(push)
+#  pragma warning(disable:4250)
+#endif
+
+namespace CGAL {
 
 // =================
 // class declaration
@@ -54,6 +66,10 @@ class QP_partial_filtered_pricing
     typedef  typename Tags::Is_nonnegative           Is_nonnegative;
     typedef  typename Partial_base::Index_iterator        Index_iterator;
     typedef  typename Partial_base::Index_const_iterator  Index_const_iterator;
+
+    using Base::price_dantzig;
+    using Base::is_improving;
+
   public:
 
     // number type
@@ -142,7 +158,7 @@ pricing_helper(int& /*direction*/, Tag_true /*is_in_standard_form*/ )
 	  continue;
 
 	// compute mu_j
-	mu = mu_j_NT( *it);
+	mu = this->mu_j_NT( *it);
 
 	CGAL_qpe_debug {
 	    this->vout() << "  mu_" << *it << " [NT]: " << mu << std::endl;
@@ -154,7 +170,7 @@ pricing_helper(int& /*direction*/, Tag_true /*is_in_standard_form*/ )
 
     // exact check of entering variable
     if ( min_mu < this->nt0) {
-	if ( mu_j( *min_it) >= this->et0) {
+	if ( this->mu_j( *min_it) >= this->et0) {
 
 	    // exact check failed!
 	    CGAL_qpe_debug {
@@ -186,7 +202,7 @@ pricing_helper(int& /*direction*/, Tag_true /*is_in_standard_form*/ )
 	    if (this->solver().is_artificial( *it)) continue;
 
 	    // compute mu_j
-	    mu = mu_j_NT( *it);
+	    mu = this->mu_j_NT( *it);
 
 	    CGAL_qpe_debug {
 		this->vout() << "  mu_" << *it << " [NT]: " << mu << std::endl;
@@ -197,7 +213,7 @@ pricing_helper(int& /*direction*/, Tag_true /*is_in_standard_form*/ )
 
 		// make variable active
 		active_it = it;
-		activating( active_it);
+		this->activating( active_it);
 
 		// new minimum?
 		if ( mu < min_mu) { min_it = active_it; min_mu = mu; }
@@ -206,7 +222,7 @@ pricing_helper(int& /*direction*/, Tag_true /*is_in_standard_form*/ )
 
 	// exact check of entering variable
 	if ( min_mu < this->nt0) {
-	    if ( mu_j( *min_it) >= this->et0) {
+	    if ( this->mu_j( *min_it) >= this->et0) {
 
 		// exact check failed!
 		CGAL_qpe_debug {
@@ -237,7 +253,7 @@ pricing_helper(int& /*direction*/, Tag_true /*is_in_standard_form*/ )
 	    if (this->solver().is_artificial( *it)) continue;
 
 	    // certify 'mu_j >= 0'
-	    if ( ! certify_mu_j_NT( *it)) {
+	    if ( ! this->certify_mu_j_NT( *it)) {
 
 		// entering variable missed by inexact arithmetic
 		min_it = it;
@@ -252,7 +268,7 @@ pricing_helper(int& /*direction*/, Tag_true /*is_in_standard_form*/ )
     // return index of entering variable, if any
     if ( min_mu < this->nt0) {
 	int  j = *min_it;
-	entering_basis( min_it);
+        this->entering_basis( min_it);
 	return j;
     }
 
@@ -282,7 +298,7 @@ pricing_helper(int& direction, Tag_false /*is_in_standard_form*/ )
 	  continue;
 
 	// compute mu_j
-	mu = mu_j_NT( *it);
+	mu = this->mu_j_NT( *it);
 
 	if (price_dantzig (*it, mu, this->nt0, min_j, min_mu, direction))
 	  min_it = it;
@@ -324,7 +340,7 @@ pricing_helper(int& direction, Tag_false /*is_in_standard_form*/ )
 	    if (this->solver().is_artificial( *it)) continue;
 
 	    // compute mu_j
-	    mu = mu_j_NT( *it);
+	    mu = this->mu_j_NT( *it);
 
 	    CGAL_qpe_debug {
 		this->vout() << "  mu_" << *it << " [NT]: " << mu << std::endl;
@@ -335,7 +351,7 @@ pricing_helper(int& direction, Tag_false /*is_in_standard_form*/ )
 
 		// make variable active
 		active_it = it;
-		activating( active_it);
+		this->activating( active_it);
 		
 		// new minimum
 		if (price_dantzig (*active_it, mu, this->nt0, 
@@ -381,7 +397,7 @@ pricing_helper(int& direction, Tag_false /*is_in_standard_form*/ )
 	    // don't price artificial variables
 	    if (this->solver().is_artificial( *it)) continue;
 
-	    if ( ! certify_mu_j_NT( *it)) {
+	    if ( ! this->certify_mu_j_NT( *it)) {
 
 		// entering variable missed by inexact arithmetic
 	      min_j = *it;
@@ -397,7 +413,7 @@ pricing_helper(int& direction, Tag_false /*is_in_standard_form*/ )
     // return index of entering variable, if any
     if ( min_j >= 0) {
       CGAL_qpe_assertion(min_j == *min_it);
-      entering_basis( min_it);
+      this->entering_basis( min_it);
       return min_j;
     }
 
@@ -405,7 +421,11 @@ pricing_helper(int& direction, Tag_false /*is_in_standard_form*/ )
     return -1;
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
+
+#if defined(BOOST_MSVC)
+#  pragma warning(pop)
+#endif
 
 #endif // CGAL_QP_PARTIAL_FILTERED_PRICING_H
 
