@@ -1,13 +1,14 @@
-// Copyright (c) 2000  Utrecht University (The Netherlands),
-// ETH Zurich (Switzerland), Freie Universitaet Berlin (Germany),
-// INRIA Sophia-Antipolis (France), Martin-Luther-University Halle-Wittenberg
-// (Germany), Max-Planck-Institute Saarbruecken (Germany), RISC Linz (Austria),
-// and Tel-Aviv University (Israel).  All rights reserved.
+// Copyright (c) 2000  
+// Utrecht University (The Netherlands),
+// ETH Zurich (Switzerland),
+// INRIA Sophia-Antipolis (France),
+// Max-Planck-Institute Saarbruecken (Germany),
+// and Tel-Aviv University (Israel).  All rights reserved. 
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -15,8 +16,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Intersections_2/include/CGAL/Ray_2_Bbox_2_intersection.h $
-// $Id: Ray_2_Bbox_2_intersection.h 56667 2010-06-09 07:37:13Z sloriot $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Intersections_2/include/CGAL/Ray_2_Bbox_2_intersection.h $
+// $Id: Ray_2_Bbox_2_intersection.h 67093 2012-01-13 11:22:39Z lrineau $
 // 
 //
 // Author(s)     : Geert-Jan Giezeman
@@ -34,7 +35,7 @@ namespace CGAL {
 
 class Bbox_2_Ray_2_pair_impl;
 
-class Bbox_2_Ray_2_pair {
+class CGAL_EXPORT Bbox_2_Ray_2_pair {
 public:
     enum Intersection_results {NO_INTERSECTION, POINT, SEGMENT};
     ~Bbox_2_Ray_2_pair() ;
@@ -50,7 +51,7 @@ protected:
     Bbox_2_Ray_2_pair_impl *pimpl;
 };
 
-bool do_intersect_ray_2(
+CGAL_EXPORT bool do_intersect_ray_2(
     const Bbox_2 &box, double x, double y, double dx, double dy);
 
 template <class Ray>
