@@ -1,9 +1,10 @@
 // Copyright (c) 1999-2004  INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Triangulation_3/include/CGAL/Regular_triangulation_3.h $
-// $Id: Regular_triangulation_3.h 61500 2011-03-04 07:12:17Z sloriot $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Triangulation_3/include/CGAL/Regular_triangulation_3.h $
+// $Id: Regular_triangulation_3.h 67417 2012-01-24 17:25:20Z sloriot $
 //
 //
 // Author(s)     : Monique Teillaud <Monique.Teillaud@sophia.inria.fr>
@@ -31,7 +32,8 @@
 #include <boost/bind.hpp>
 
 #ifndef CGAL_TRIANGULATION_3_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
-#include <CGAL/internal/spatial_sorting_traits_with_indices.h>
+#include <CGAL/Spatial_sort_traits_adapter_3.h>
+#include <CGAL/internal/info_check.h>
 
 #include <boost/iterator/zip_iterator.hpp>
 #include <boost/mpl/and.hpp>
@@ -158,16 +160,10 @@ public:
   std::ptrdiff_t
   insert( InputIterator first, InputIterator last,
           typename boost::enable_if<
-            boost::mpl::or_<
-              boost::is_same<
+              boost::is_convertible<
                   typename std::iterator_traits<InputIterator>::value_type,
                   Weighted_point
-              >,
-              boost::is_same<
-                  typename std::iterator_traits<InputIterator>::value_type,
-                  Bare_point
               >
-            >
           >::type* = NULL  
   )
 #else
@@ -200,6 +196,7 @@ public:
   
 #ifndef CGAL_TRIANGULATION_3_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
 private:
+  //top stands for tuple-or-pair
   template <class Info>
   const Weighted_point& top_get_first(const std::pair<Weighted_point,Info>& pair) const { return pair.first; }
   template <class Info>
@@ -213,10 +210,10 @@ private:
   std::ptrdiff_t insert_with_info(InputIterator first,InputIterator last)
   {
     size_type n = number_of_vertices();
-    std::vector<std::size_t> indices;
+    std::vector<std::ptrdiff_t> indices;
     std::vector<Weighted_point> points;
     std::vector<typename Triangulation_data_structure::Vertex::Info> infos;
-    std::size_t index=0;
+    std::ptrdiff_t index=0;
     for (InputIterator it=first;it!=last;++it){
       Tuple_or_pair pair = *it;
       points.push_back( top_get_first(pair) );
@@ -224,13 +221,12 @@ private:
       indices.push_back(index++);
     }
 
-    typedef internal::Vector_property_map<Weighted_point> Point_pmap;
-    typedef internal::Spatial_sort_traits_with_property_map_3<Geom_traits,Point_pmap> Search_traits;
+    typedef Spatial_sort_traits_adapter_3<Geom_traits,Weighted_point*> Search_traits;
     
-    spatial_sort(indices.begin(),indices.end(),Search_traits(Point_pmap(points),geom_traits()));    
+    spatial_sort( indices.begin(),indices.end(),Search_traits(&(points[0]),geom_traits()) );
 
     Cell_handle hint;
-    for (typename std::vector<std::size_t>::const_iterator
+    for (typename std::vector<std::ptrdiff_t>::const_iterator
       it = indices.begin(), end = indices.end();
       it != end; ++it)
     {
@@ -258,16 +254,10 @@ public:
   insert( InputIterator first,
           InputIterator last,
           typename boost::enable_if<
-            boost::mpl::or_<
-              boost::is_same<
+              boost::is_convertible<
                 typename std::iterator_traits<InputIterator>::value_type,
                 std::pair<Weighted_point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type>
-              >,
-              boost::is_same<
-                typename std::iterator_traits<InputIterator>::value_type,
-                std::pair<Bare_point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type>
               >
-            >
           >::type* = NULL
   )
   {return insert_with_info< std::pair<Weighted_point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type> >(first,last);}
@@ -278,11 +268,8 @@ public:
           boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > last,
           typename boost::enable_if<
             boost::mpl::and_<
-              boost::mpl::or_<
-                typename boost::is_same< typename std::iterator_traits<InputIterator_1>::value_type, Weighted_point >,
-                typename boost::is_same< typename std::iterator_traits<InputIterator_1>::value_type, Bare_point >
-              >,
-              typename boost::is_same< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type >
+              typename boost::is_convertible< typename std::iterator_traits<InputIterator_1>::value_type, Weighted_point >,
+              typename boost::is_convertible< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type >
             >
           >::type* =NULL
   )
