@@ -1,9 +1,10 @@
 // Copyright (c) 1997  INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Triangulation_2/include/CGAL/Regular_triangulation_vertex_base_2.h $
-// $Id: Regular_triangulation_vertex_base_2.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Triangulation_2/include/CGAL/Regular_triangulation_vertex_base_2.h $
+// $Id: Regular_triangulation_vertex_base_2.h 67117 2012-01-13 18:14:48Z lrineau $
 // 
 //
 // Author(s)     : Andreas Fabri
@@ -23,7 +24,7 @@
 
 #include <CGAL/Triangulation_ds_vertex_base_2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template < class GT,
            class Vb = Triangulation_ds_vertex_base_2<> >
@@ -63,7 +64,7 @@ public:
   bool is_hidden() { return _hidden ;}
   void set_point(const Weighted_point & p) { _p = p; }
   const Weighted_point&  point() const { return _p; }
-  //Weighted_point&  point() const { return _p; }
+  Weighted_point&  point() { return _p; }
   bool is_valid(bool /* verbose */ = false, int /* level */ = 0) const
     {return true;}
 };
@@ -88,7 +89,7 @@ operator<<(std::ostream &os,
   return os << static_cast<const Vb&>(v) << v.point();
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 
 #endif //CGAL_REGULAR_TRIANGULATION_VERTEX_BASE_2_H
