@@ -1,9 +1,10 @@
 // Copyright (c) 1997  ETH Zurich (Switzerland).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/SearchStructures/include/CGAL/Segment_tree_k.h $
-// $Id: Segment_tree_k.h 41371 2007-12-30 16:55:25Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/SearchStructures/include/CGAL/Segment_tree_k.h $
+// $Id: Segment_tree_k.h 67117 2012-01-13 18:14:48Z lrineau $
 // 
 //
 // Author(s)     : Gabriele Neyer
@@ -35,7 +36,7 @@
 #include <CGAL/Tree_traits.h>
 #include <CGAL/Segment_tree_d.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class C_Traits_1>
 class Segment_tree_1
@@ -443,6 +444,6 @@ public:
   }
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
