@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Number_types/include/CGAL/Sqrt_extension.h $
-// $Id: Sqrt_extension.h 47264 2008-12-08 06:25:14Z hemmer $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Number_types/include/CGAL/Sqrt_extension.h $
+// $Id: Sqrt_extension.h 67093 2012-01-13 11:22:39Z lrineau $
 //
 //
 // Author(s)     : Michael Hemmer   <hemmer@mpi-inf.mpg.de>
@@ -62,6 +62,10 @@ factorization property.
 #include <CGAL/Sqrt_extension/Algebraic_extension_traits.h>
 #include <CGAL/Sqrt_extension/Chinese_remainder_traits.h>
 #include <CGAL/Sqrt_extension/io.h>
+#include <CGAL/Sqrt_extension/Get_arithmetic_kernel.h>
+#include <CGAL/Sqrt_extension/convert_to_bfi.h>
+#include <CGAL/Sqrt_extension/Wang_traits.h>
+
 
 #endif  // CGAL_SQRT_EXTENSION_H
 
