@@ -1,8 +1,9 @@
 // Copyright (c) 2005-2008 Fernando Luis Cacciola Carballal. All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -10,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Straight_skeleton_2/include/CGAL/Straight_skeleton_face_base_2.h $
-// $Id: Straight_skeleton_face_base_2.h 41590 2008-01-14 13:44:13Z fcacciola $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Straight_skeleton_2/include/CGAL/Straight_skeleton_face_base_2.h $
+// $Id: Straight_skeleton_face_base_2.h 67117 2012-01-13 18:14:48Z lrineau $
 //
 // Author(s)     : Fernando Cacciola <fernando_cacciola@ciudad.com.ar>
 //
@@ -19,7 +20,7 @@
 #define CGAL_STRAIGHT_SKELETON_FACE_BASE_2_H 1
 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class Refs>
 class Straight_skeleton_face_base_base_2
@@ -83,7 +84,7 @@ private:
 
 } ;
 
-CGAL_END_NAMESPACE
+} // end namespace CGAL
 
 #endif // CGAL_STRAIGHT_SKELETON_FACE_BASE_2_H //
 // EOF //
