@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kinetic_data_structures/include/CGAL/Tools/Log.h $
-// $Id: Log.h 41622 2008-01-14 22:01:20Z drussel $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Kinetic_data_structures/include/CGAL/Tools/Log.h $
+// $Id: Log.h 67093 2012-01-13 11:22:39Z lrineau $
 // 
 //
 // Author(s)     : Daniel Russel <drussel@alumni.princeton.edu>
@@ -26,7 +26,14 @@
 #include <fstream>
 #include <ios>
 
-CGAL_BEGIN_NAMESPACE
+#if defined(BOOST_MSVC)
+// Disable the warning about dll-interface needed for std::ofstream members
+// of Log::State.
+#  pragma warning(push)
+#  pragma warning(disable:4251)
+#endif
+
+namespace CGAL {
 
 class Log
 {
@@ -35,7 +42,7 @@ public:
   
   enum Target {COUT, FILE, DEVNULL};
 private:
-  struct State {
+  struct CGAL_EXPORT State {
     Target target_;
     Level level_;
     std::ofstream fstream_;
@@ -52,7 +59,7 @@ private:
       output_maple_=true;
     }
   };
-  static State state_;
+  CGAL_EXPORT static State state_;
 public:
   // The different types of logs supported
   /*  MAPLE is a log which should be able to be fed directly in to
@@ -150,5 +157,12 @@ struct Set_log_state{
   Log::Level old_level_;
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
+
+#if defined(BOOST_MSVC)
+#  pragma warning(pop)
 #endif
+
+#endif
+
+
