@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Installation/include/CGAL/auto_link/CGALQt3.h $
-// $Id: CGALQt3.h 62998 2011-04-15 08:43:49Z eric $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Installation/include/CGAL/auto_link/CGALQt3.h $
+// $Id: CGALQt3.h 67093 2012-01-13 11:22:39Z lrineau $
 // 
 //
 // Author(s)     : Fernando Cacciola (fernando.cacciola@geometryfactry.com)
@@ -20,6 +20,8 @@
 #ifndef CGAL_AUTO_LINK_CGALQT_H
 #define CGAL_AUTO_LINK_CGALQT_H
 
+#include <CGAL/config.h>
+
 #ifndef CGAL_NO_AUTOLINK_CGALQT
 
 #define CGAL_LIB_NAME CGAL_Qt3
