@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Installation/include/CGAL/auto_link/ImageIO.h $
-// $Id: ImageIO.h 39183 2007-06-21 13:01:06Z fcacciola $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Installation/include/CGAL/auto_link/ImageIO.h $
+// $Id: ImageIO.h 67093 2012-01-13 11:22:39Z lrineau $
 // 
 //
 // Author(s)     : Fernando Cacciola (fernando.cacciola@geometryfactry.com)
@@ -20,12 +20,19 @@
 #ifndef CGAL_AUTO_LINK_IMAGEIO_H
 #define CGAL_AUTO_LINK_IMAGEIO_H
 
-#ifndef CGAL_NO_AUTOLINK_IMAGEIO
+#include <CGAL/config.h>
 
-#define CGAL_LIB_NAME CGALimageIO
+#ifndef CGAL_NO_AUTOLINK_IMAGEIO
+#if ( ! defined( CGAL_EXPORTS ) ) && (! defined ( CGAL_ImageIO_EXPORTS ) ) 
+
+// If CGAL_EXPORTS is defined it means that we are building the CGAL
+// library as a DLL. The CGAL.dll does not really depend on CGAL_ImageIO,
+// whatever the header inclusion graph says.
+
+#define CGAL_LIB_NAME CGAL_ImageIO
 #include <CGAL/auto_link/auto_link.h>
 
+#endif // CGAL_EXPORTS
 #endif // CGAL_NO_AUTOLINK_IMAGEIO
 
 #endif // CGAL_AUTO_LINK_IMAGEIO_H
-
