@@ -1,13 +1,14 @@
-// Copyright (c) 1998  Utrecht University (The Netherlands),
-// ETH Zurich (Switzerland), Freie Universitaet Berlin (Germany),
-// INRIA Sophia-Antipolis (France), Martin-Luther-University Halle-Wittenberg
-// (Germany), Max-Planck-Institute Saarbruecken (Germany), RISC Linz (Austria),
-// and Tel-Aviv University (Israel).  All rights reserved.
+// Copyright (c) 1998  
+// Utrecht University (The Netherlands),
+// ETH Zurich (Switzerland),
+// INRIA Sophia-Antipolis (France),
+// Max-Planck-Institute Saarbruecken (Germany),
+// and Tel-Aviv University (Israel).  All rights reserved. 
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
-// See the file LICENSE.LGPL distributed with CGAL.
+// published by the Free Software Foundation; either version 3 of the License,
+// or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -15,8 +16,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Generator/include/CGAL/random_convex_set_2.h $
-// $Id: random_convex_set_2.h 48717 2009-04-08 11:54:51Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Generator/include/CGAL/random_convex_set_2.h $
+// $Id: random_convex_set_2.h 67093 2012-01-13 11:22:39Z lrineau $
 // 
 //
 // Author(s)     : Michael Hoffmann <hoffmann@inf.ethz.ch>
@@ -32,11 +33,11 @@
 #include <CGAL/Random_convex_set_traits_2.h>
 #include <CGAL/centroid.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template < class OutputIterator, class Point_generator, class Traits >
 OutputIterator
-random_convex_set_2( int n,
+random_convex_set_2( std::size_t n,
                      OutputIterator o,
                      const Point_generator& pg,
                      Traits t)
@@ -52,7 +53,7 @@ random_convex_set_2( int n,
   using std::partial_sum;
   using std::less;
   using std::max_element;
-  using CGAL::copy_n;
+  using CGAL::cpp0x::copy_n;
 
   typedef typename Traits::Point_2         Point_2;
   typedef typename Traits::FT              FT;
@@ -71,7 +72,7 @@ random_convex_set_2( int n,
   // build random point set:
   Container points;
   points.reserve( n);
-  CGAL::copy_n( pg, n, back_inserter( points));
+  CGAL::cpp0x::copy_n( pg, n, back_inserter( points));
 
   // compute centroid of points:
   Point_2 centroid = CGAL::centroid( points.begin(), points.end(), t );
@@ -119,6 +120,6 @@ random_convex_set_2( int n,
 
 } // random_convex_set_2( n, o, pg, t)
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // ! (CGAL_RANDOM_CONVEX_SET_2_H)
