@@ -1,9 +1,10 @@
 // Copyright (c) 2003  INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
+// You can redistribute it and/or modify it under the terms of the GNU
+// General Public License as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
@@ -11,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Interpolation/include/CGAL/regular_neighbor_coordinates_2.h $
-// $Id: regular_neighbor_coordinates_2.h 40822 2007-11-07 16:51:18Z ameyer $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Interpolation/include/CGAL/regular_neighbor_coordinates_2.h $
+// $Id: regular_neighbor_coordinates_2.h 67117 2012-01-13 18:14:48Z lrineau $
 // 
 //
 // Author(s)     : Julia Floetotto
@@ -26,7 +27,7 @@
 //for definition of class Project_vertex_output_iterator
 #include <CGAL/natural_neighbor_coordinates_2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 // in this functions, the traits class is defined via the regular
 // triangulation
@@ -88,6 +89,8 @@ regular_neighbor_coordinates_vertex_2(const Rt& rt,
   typedef typename Rt::Edge               Edge;
   typedef typename Rt::Locate_type        Locate_type;
 
+  CGAL_precondition(rt.dimension() == 2);
+  
   Locate_type lt;
   int li;
   Face_handle fh = rt.locate(p, lt, li, start);
@@ -311,6 +314,8 @@ regular_neighbor_coordinates_2(const Rt& rt,
   // recomputation)
   Project_vertex_output_iterator<OutputIterator> op(out);
 
+  CGAL_precondition(rt.dimension() == 2);
+  
   Triple< Project_vertex_output_iterator<OutputIterator>,
     typename Rt::Geom_traits::FT, bool >  result =
     regular_neighbor_coordinates_vertex_2
@@ -383,6 +388,8 @@ regular_neighbor_coordinates_2(const Rt& rt,
   // natural neighbor coordinates of vh->point() wrt. it.
   typedef typename Rt::Vertex_circulator     Vertex_circulator;
 
+  CGAL_precondition(rt.dimension() == 2);
+  
   Rt t2;
   Vertex_circulator vc = rt.incident_vertices(vh),
     done(vc);
@@ -412,6 +419,6 @@ public:
   }
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_REGULAR_NEIGHBOR_COORDINATES_2_H
